Learn R Programming

wikiprofiler (version 0.1.5)

wpplot: Input specific wikipathways ID to get an output in class of wpplot.

Description

Use wikipathways ID to open a local svg file. Then extract related information from svg file and build a wpplot class variance.

Usage

wpplot(ID)

Value

A 'wpplot' object

Arguments

ID

ID is wikipathways' ID.

Examples

Run this code
if (yulab.utils::has_internet())
   wpplot('WP179') 

Run the code above in your browser using DataLab